@@ -63,11 +63,14 @@ struct _CryptUIKeysetClass {
 
 GType               cryptui_keyset_get_type           (void);
 
-CryptUIKeyset*      cryptui_keyset_new                (const gchar *keytype);
+CryptUIKeyset*      cryptui_keyset_new                (const gchar *keytype, 
+                                                       gboolean expand_keys);
 
 gboolean            cryptui_keyset_has_key            (CryptUIKeyset *keyset,
                                                        const gchar *key);
 
+const gchar*        cryptui_keyset_get_keytype        (CryptUIKeyset *keyset);
+
 GList*              cryptui_keyset_get_keys           (CryptUIKeyset *keyset);
 
 guint               cryptui_keyset_get_count          (CryptUIKeyset *keyset);
@@ -80,6 +83,11 @@ gpointer            cryptui_keyset_get_closure        (CryptUIKeyset *keyset,
 void                cryptui_keyset_set_closure        (CryptUIKeyset *keyset,
                                                        const gchar *key,
                                                        gpointer closure);
+
+gboolean            cryptui_keyset_get_expand_keys    (CryptUIKeyset *keyset);
+
+void                cryptui_keyset_set_expand_keys    (CryptUIKeyset *keyset,
+                                                       gboolean expand_keys);
                                                        
 void                cryptui_keyset_cache_key          (CryptUIKeyset *keyset,
                                                        const gchar *key);
@@ -101,6 +109,12 @@ gchar*              cryptui_keyset_key_display_name   (CryptUIKeyset *keyset,
 gchar*              cryptui_keyset_key_display_id     (CryptUIKeyset *keyset, 
                                                        const gchar *key);
 
+gchar*              cryptui_keyset_key_raw_keyid      (CryptUIKeyset *keyset,
+                                                       const gchar *key);
+                                                       
+gchar**             cryptui_keyset_keys_raw_keyids    (CryptUIKeyset *keyset,
+                                                       const gchar **keys);
+
 /* TODO: A way to change the key properties ve cache */
 
 #endif /* __CRYPTUI_KEYSET_H__ */
