@@ -97,7 +97,8 @@ typedef enum {
     SKEY_ETYPE_NONE =       CRYPTUI_ENCTYPE_NONE,       /* Any encryption type */
     SKEY_SYMMETRIC =        CRYPTUI_ENCTYPE_SYMMETRIC,  /* A symmetric key */
     SKEY_PUBLIC =           CRYPTUI_ENCTYPE_PUBLIC,     /* A public key */
-    SKEY_PRIVATE =          CRYPTUI_ENCTYPE_PRIVATE     /* A private key (assumes public/keypair)*/
+    SKEY_PRIVATE =          CRYPTUI_ENCTYPE_PRIVATE,    /* A private key (assumes public/keypair) */
+    SKEY_CREDENTIALS                                    /* Credentials (ie: from gnome-keyring) */
 } SeahorseKeyEType;
 
 typedef enum {
@@ -127,6 +128,7 @@ typedef enum {
 
 /* Forward declaration */
 struct _SeahorseKeySource;
+struct _SeahorseContext;
 
 typedef struct _SeahorseKey SeahorseKey;
 typedef struct _SeahorseKeyClass SeahorseKeyClass;
@@ -144,6 +146,9 @@ struct _SeahorseKey {
     SeahorseKeyEType            etype;
     guint                       flags;
     struct _SeahorseKeySource*  sksrc;
+
+    /*< private >*/
+    struct _SeahorseContext*    attached_to;
     struct _SeahorseKey*        preferred;
 };
 
