@@ -115,14 +115,36 @@ get_ldap_server_info (SeahorseLDAPSource *lsrc, gboolean force)
  
 #define LDAP_ERROR_DOMAIN (get_ldap_error_domain())
 
+static gchar**
+get_ldap_values (LDAP *ld, LDAPMessage *entry, const char *attribute)
+{
+    GArray *array;
+    struct berval **bv;
+    gchar *value;
+    int num, i;
+
+    bv = ldap_get_values_len (ld, entry, attribute);
+    if (!bv)
+        return NULL;
+
+    array = g_array_new (TRUE, TRUE, sizeof (gchar*));
+    num = ldap_count_values_len (bv);
+    for(i = 0; i < num; i++) {
+        value = g_strndup (bv[i]->bv_val, bv[i]->bv_len);
+        g_array_append_val(array, value);
+    }
+
+    return (gchar**)g_array_free (array, FALSE);
+}
+
 #if DEBUG_LDAP_ENABLE
 
 static void
 dump_ldap_entry (LDAP *ld, LDAPMessage *res)
 {
     BerElement *pos;
-    char **values;
-    char **v;
+    gchar **values;
+    gchar **v;
     char *t;
     
     t = ldap_get_dn (ld, res);
@@ -132,11 +154,11 @@ dump_ldap_entry (LDAP *ld, LDAPMessage *res)
     for (t = ldap_first_attribute (ld, res, &pos); t; 
          t = ldap_next_attribute (ld, res, pos)) {
              
-        values = ldap_get_values (ld, res, t);
+        values = get_ldap_values (ld, res, t);
         for (v = values; *v; v++) 
             g_printerr ("%s: %s\n", t, *v);
              
-        ldap_value_free (values);
+        g_strfreev (values);
         ldap_memfree (t);
     }
     
@@ -155,44 +177,44 @@ get_ldap_error_domain ()
 }
 
 static gchar*
-get_string_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
+get_string_attribute (LDAP *ld, LDAPMessage *res, const char *attribute)
 {
-    char **vals;
+    gchar **vals;
     gchar *v;
     
-    vals = ldap_get_values (ld, res, attribute);
+    vals = get_ldap_values (ld, res, attribute);
     if (!vals)
         return NULL; 
     v = vals[0] ? g_strdup (vals[0]) : NULL;
-    ldap_value_free (vals);
+    g_strfreev (vals);
     return v;
 }
 
 static gboolean
 get_boolean_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
 {
-    char **vals;
+    gchar **vals;
     gboolean b;
     
-    vals = ldap_get_values (ld, res, attribute);
+    vals = get_ldap_values (ld, res, attribute);
     if (!vals)
         return FALSE;
     b = vals[0] && atoi (vals[0]) == 1;
-    ldap_value_free (vals);
+    g_strfreev (vals);
     return b;
 }
 
 static long int
 get_int_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
 {
-    char **vals;
+    gchar **vals;
     long int d;
     
-    vals = ldap_get_values (ld, res, attribute);
+    vals = get_ldap_values (ld, res, attribute);
     if (!vals)
         return 0;
     d = vals[0] ? atoi (vals[0]) : 0;
-    ldap_value_free (vals);
+    g_strfreev (vals);
     return d;         
 }
 
@@ -200,10 +222,10 @@ static long int
 get_date_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
 {
     struct tm t;
-    char **vals;
+    gchar **vals;
     long int d;
     
-    vals = ldap_get_values (ld, res, attribute);
+    vals = get_ldap_values (ld, res, attribute);
     if (!vals)
         return 0;
         
@@ -222,7 +244,7 @@ get_date_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
         d = mktime (&t);
     }        
 
-    ldap_value_free (vals);
+    g_strfreev (vals);
     return d;         
 }
 
@@ -230,9 +252,9 @@ static gpgme_pubkey_algo_t
 get_algo_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
 {
     gpgme_pubkey_algo_t a = 0;
-    char **vals;
+    gchar **vals;
     
-    vals = ldap_get_values (ld, res, attribute);
+    vals = get_ldap_values (ld, res, attribute);
     if (!vals)
         return 0;
     
@@ -247,22 +269,26 @@ get_algo_attribute (LDAP* ld, LDAPMessage *res, const char *attribute)
             a = GPGME_PK_DSA;     
     }
     
-    ldap_value_free (vals);
+    g_strfreev (vals);
     return a;
 }
 
-/* Escapes a value so it's safe to use in an LDAP filter */
+/* 
+ * Escapes a value so it's safe to use in an LDAP filter. Also trims
+ * any spaces which cause problems with some LDAP servers.
+ */
 static gchar*
 escape_ldap_value (const gchar *v)
 {
     GString *value;
+    gchar* result;
     
     g_assert (v);
     value = g_string_sized_new (strlen(v));
     
     for ( ; *v; v++) {
         switch(*v) {
-        case ' ': case '#': case ',': case '+': case '\\':
+        case '#': case ',': case '+': case '\\':
         case '/': case '\"': case '<': case '>': case ';':
             value = g_string_append_c (value, '\\');
             value = g_string_append_c (value, *v);
@@ -277,7 +303,9 @@ escape_ldap_value (const gchar *v)
         value = g_string_append_c (value, *v);
     }
     
-    return g_string_free (value, FALSE);
+    result = g_string_free (value, FALSE);
+    g_strstrip (result);
+    return result;
 }
 
 /* -----------------------------------------------------------------------------
@@ -343,12 +371,12 @@ seahorse_ldap_operation_dispose (GObject *gobject)
     
     if (lop->ldap_op != -1) {
         if (lop->ldap)
-            ldap_abandon (lop->ldap, lop->ldap_op);
+            ldap_abandon_ext (lop->ldap, lop->ldap_op, NULL, NULL);
         lop->ldap_op = -1;
     }
 
     if (lop->ldap) {
-        ldap_unbind (lop->ldap);
+        ldap_unbind_ext (lop->ldap, NULL, NULL);
         lop->ldap = NULL;
     }
     
@@ -390,12 +418,12 @@ seahorse_ldap_operation_cancel (SeahorseOperation *operation)
     
     if (lop->ldap_op != -1) {
         if (lop->ldap)
-            ldap_abandon (lop->ldap, lop->ldap_op);
+            ldap_abandon_ext (lop->ldap, lop->ldap_op, NULL, NULL);
         lop->ldap_op = -1;
     }
 
     if (lop->ldap) {
-        ldap_unbind (lop->ldap);
+        ldap_unbind_ext (lop->ldap, NULL, NULL);
         lop->ldap = NULL;
     }
 
@@ -505,7 +533,7 @@ done_info_start_op (SeahorseOperation *op, LDAPMessage *result)
             sinfo->key_attr = g_strdup (sinfo->version > 1 ? "pgpkeyv2" : "pgpkey");
             set_ldap_server_info (lop->lsrc, sinfo);
             
-            ldap_abandon (lop->ldap, lop->ldap_op);
+            ldap_abandon_ext (lop->ldap, lop->ldap_op, NULL, NULL);
             lop->ldap_op = -1;
             
         } else {
@@ -560,10 +588,11 @@ done_bind_start_info (SeahorseOperation *op, LDAPMessage *result)
         return done_info_start_op (op, NULL);
         
     /* Retrieve the server info */
-    lop->ldap_op = ldap_search (lop->ldap, "cn=PGPServerInfo", LDAP_SCOPE_BASE,
-                                "(objectclass=*)", (char**)kServerAttributes, 0);    
-    if (lop->ldap_op == -1) {
-        fail_ldap_operation (lop, 0);
+    r = ldap_search_ext (lop->ldap, "cn=PGPServerInfo", LDAP_SCOPE_BASE,
+                         "(objectclass=*)", (char**)kServerAttributes, 0,
+                         NULL, NULL, NULL, 0, &(lop->ldap_op));    
+    if (r != LDAP_SUCCESS) {
+        fail_ldap_operation (lop, r);
         return FALSE;
     }
 
@@ -625,7 +654,7 @@ resolved_callback (gpointer unused, guint status, SeahorseLDAPOperation *lop)
     /* The ldap_cb and chain_cb were set in seahorse_ldap_operation_start */
     
     t = g_strdup_printf (_("Connecting to: %s"), server);
-    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, 0.0);
+    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, -1);
     g_free (t);
 
     g_free (server);
@@ -674,7 +703,7 @@ seahorse_ldap_operation_start (SeahorseLDAPSource *lsrc, OpLDAPCallback cb,
     lop->addr = soup_address_new (server, LDAP_PORT);
     
     t = g_strdup_printf (_("Resolving server address: %s"), server);
-    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, 0.0);
+    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, -1);
     g_free (t);
 
     g_free (server);
@@ -804,6 +833,7 @@ start_search (SeahorseOperation *op, LDAPMessage *result)
     SeahorseLDAPOperation *lop = SEAHORSE_LDAP_OPERATION (op);  
     LDAPServerInfo *sinfo;
     gchar *filter, *t;
+    int r;
     
     g_return_val_if_fail (lop->ldap != NULL, FALSE);
     g_assert (lop->ldap_op == -1);
@@ -812,13 +842,18 @@ start_search (SeahorseOperation *op, LDAPMessage *result)
     g_return_val_if_fail (filter != NULL, FALSE);
 
     t = (gchar*)g_object_get_data (G_OBJECT (lop), "details");
-    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, 0.0);
+    seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), t, -1);
     
     sinfo = get_ldap_server_info (lop->lsrc, TRUE);
-    lop->ldap_op = ldap_search (lop->ldap, sinfo->base_dn, LDAP_SCOPE_SUBTREE,
-                                filter, (char**)kPGPAttributes, 0);
-    if (lop->ldap_op == -1) {
-        fail_ldap_operation (lop, 0);
+
+    DEBUG_LDAP (("[ldap] Searching Server ... base: %s, filter: %s\n", 
+                 sinfo->base_dn, filter));
+    
+    r = ldap_search_ext (lop->ldap, sinfo->base_dn, LDAP_SCOPE_SUBTREE,
+                         filter, (char**)kPGPAttributes, 0,
+                         NULL, NULL, NULL, 0, &(lop->ldap_op));    
+    if (r != LDAP_SUCCESS) {
+        fail_ldap_operation (lop, r);
         return FALSE;
     }                                    
     
@@ -912,7 +947,7 @@ get_callback (SeahorseOperation *op, LDAPMessage *result)
         key = get_string_attribute (lop->ldap, result, sinfo->key_attr);
         
         if (key == NULL) {
-            g_warning ("keyserver missing pgp key data");
+            g_warning ("key server missing pgp key data");
             fail_ldap_operation (lop, LDAP_NO_SUCH_OBJECT); 
         }
         
@@ -963,7 +998,7 @@ get_key_from_ldap (SeahorseOperation *op, LDAPMessage *result)
     gchar *filter;
     char *attrs[2];
     const gchar *fpr;
-    int l;
+    int l, r;
     
     g_assert (lop->ldap != NULL);
     g_assert (lop->ldap_op == -1);
@@ -995,13 +1030,13 @@ get_key_from_ldap (SeahorseOperation *op, LDAPMessage *result)
         attrs[0] = sinfo->key_attr;
         attrs[1] = NULL;
         
-        lop->ldap_op = ldap_search (lop->ldap, sinfo->base_dn, LDAP_SCOPE_SUBTREE,
-                                    filter, attrs, 0);
-
+        r = ldap_search_ext (lop->ldap, sinfo->base_dn, LDAP_SCOPE_SUBTREE,
+                             filter, attrs, 0,
+                             NULL, NULL, NULL, 0, &(lop->ldap_op));
         g_free (filter);
 
-        if (lop->ldap_op == -1) {
-            fail_ldap_operation (lop, 0);
+        if (r != LDAP_SUCCESS) {
+            fail_ldap_operation (lop, r);
             return FALSE;
         }                                    
                 
@@ -1096,6 +1131,7 @@ send_key_to_ldap (SeahorseOperation *op, LDAPMessage *result)
     LDAPMod *attrs[2];
     char *values[2];
     guint l;
+    int r;
 
     g_assert (lop->ldap != NULL);
     g_assert (lop->ldap_op == -1);
@@ -1132,12 +1168,12 @@ send_key_to_ldap (SeahorseOperation *op, LDAPMessage *result)
         
         base = g_strdup_printf ("pgpCertid=virtual,%s", sinfo->base_dn);
         
-        lop->ldap_op = ldap_add (lop->ldap, base, attrs);
+        r = ldap_add_ext (lop->ldap, base, attrs, NULL, NULL, &(lop->ldap_op));
 
         g_free (base);
-                
-        if (lop->ldap_op == -1) {
-            fail_ldap_operation (lop, 0);
+        
+        if (r != LDAP_SUCCESS) {
+            fail_ldap_operation (lop, r);
             return FALSE;
         }                                    
                 
@@ -1173,59 +1209,17 @@ start_send_operation_multiple (SeahorseLDAPSource *lsrc, GSList *keys)
  *  SEAHORSE LDAP SOURCE
  */
  
-/* GObject handlers */
-static void seahorse_ldap_source_class_init (SeahorseLDAPSourceClass *klass);
+G_DEFINE_TYPE (SeahorseLDAPSource, seahorse_ldap_source, SEAHORSE_TYPE_SERVER_SOURCE);
 
-/* SeahorseKeySource methods */
-static SeahorseOperation*  seahorse_ldap_source_load       (SeahorseKeySource *src,
-                                                            SeahorseKeySourceLoad load,
-                                                            GQuark keyid,
-                                                            const gchar *match);
-static SeahorseOperation*  seahorse_ldap_source_import     (SeahorseKeySource *sksrc, 
-                                                            gpgme_data_t data);
-static SeahorseOperation*  seahorse_ldap_source_export_raw (SeahorseKeySource *sksrc, 
-                                                            GSList *keyids,
-                                                            gpgme_data_t data);
-                                                           
-static SeahorseKeySourceClass *parent_class = NULL;
 
-GType
-seahorse_ldap_source_get_type (void)
+static void 
+seahorse_ldap_source_init (SeahorseLDAPSource *lsrc)
 {
-    static GType type = 0;
- 
-    if (!type) {
-        
-        static const GTypeInfo tinfo = {
-            sizeof (SeahorseLDAPSourceClass), NULL, NULL,
-            (GClassInitFunc) seahorse_ldap_source_class_init, NULL, NULL,
-            sizeof (SeahorseLDAPSource), 0, NULL
-        };
-        
-        type = g_type_register_static (SEAHORSE_TYPE_SERVER_SOURCE, 
-                                       "SeahorseLDAPSource", &tinfo, 0);
-    }
-  
-    return type;
-}
 
-/* Initialize the basic class stuff */
-static void
-seahorse_ldap_source_class_init (SeahorseLDAPSourceClass *klass)
-{
-    SeahorseKeySourceClass *key_class;
-   
-    key_class = SEAHORSE_KEY_SOURCE_CLASS (klass);
-    key_class->load = seahorse_ldap_source_load;
-    key_class->import = seahorse_ldap_source_import;
-    key_class->export_raw = seahorse_ldap_source_export_raw;
-
-    parent_class = g_type_class_peek_parent (klass);
 }
 
 static SeahorseOperation*
-seahorse_ldap_source_load (SeahorseKeySource *src, SeahorseKeySourceLoad load,
-                           GQuark keyid, const gchar *match)
+seahorse_ldap_source_load (SeahorseKeySource *src, GQuark keyid)
 {
     SeahorseOperation *op;
     SeahorseLDAPOperation *lop = NULL;
@@ -1233,23 +1227,35 @@ seahorse_ldap_source_load (SeahorseKeySource *src, SeahorseKeySourceLoad load,
     g_assert (SEAHORSE_IS_KEY_SOURCE (src));
     g_assert (SEAHORSE_IS_LDAP_SOURCE (src));
 
-    op = parent_class->load (src, load, keyid, match);
+    op = SEAHORSE_KEY_SOURCE_CLASS (seahorse_ldap_source_parent_class)->load (src, keyid);
     if (op != NULL)
         return op;
     
     /* No way to find new or all keys */
-    if (load == SKSRC_LOAD_NEW || load == SKSRC_LOAD_ALL) 
+    if (!keyid) 
         return seahorse_operation_new_complete (NULL);
 
+    lop = start_search_operation_fpr (SEAHORSE_LDAP_SOURCE (src), 
+                                      seahorse_key_get_rawid (keyid));
+    g_return_val_if_fail (lop != NULL, NULL);
+
+    seahorse_server_source_take_operation (SEAHORSE_SERVER_SOURCE (src),
+                                           SEAHORSE_OPERATION (lop));
+    g_object_ref (lop);
+    return SEAHORSE_OPERATION (lop);
+}
+
+static SeahorseOperation*
+seahorse_ldap_source_search (SeahorseKeySource *src, const gchar *match)
+{
+    SeahorseLDAPOperation *lop = NULL;
+
+    g_assert (SEAHORSE_IS_KEY_SOURCE (src));
+    g_assert (SEAHORSE_IS_LDAP_SOURCE (src));
+
     /* Search for keys */
-    else if (load == SKSRC_LOAD_SEARCH)
-        lop = start_search_operation (SEAHORSE_LDAP_SOURCE (src), match);
-        
-    /* Load a specific key */
-    else if (load == SKSRC_LOAD_KEY)
-        lop = start_search_operation_fpr (SEAHORSE_LDAP_SOURCE (src), 
-                                          seahorse_key_get_rawid (keyid));
-    
+    lop = start_search_operation (SEAHORSE_LDAP_SOURCE (src), match);
+     
     g_return_val_if_fail (lop != NULL, NULL);
     seahorse_server_source_take_operation (SEAHORSE_SERVER_SOURCE (src),
                                            SEAHORSE_OPERATION (lop));
@@ -1314,6 +1320,22 @@ seahorse_ldap_source_export_raw (SeahorseKeySource *sksrc, GSList *keyids,
     return SEAHORSE_OPERATION (lop);    
 }
 
+/* Initialize the basic class stuff */
+static void
+seahorse_ldap_source_class_init (SeahorseLDAPSourceClass *klass)
+{
+    SeahorseKeySourceClass *key_class;
+   
+    key_class = SEAHORSE_KEY_SOURCE_CLASS (klass);
+    key_class->load = seahorse_ldap_source_load;
+    key_class->search = seahorse_ldap_source_search;
+    key_class->import = seahorse_ldap_source_import;
+    key_class->export_raw = seahorse_ldap_source_export_raw;
+
+    seahorse_ldap_source_parent_class = g_type_class_peek_parent (klass);
+}
+
+
 /**
  * seahorse_ldap_source_new
  * @uri: The server to connect to 
