@@ -19,19 +19,29 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/**
+ * Function for displaying the preferences dialog.
+ */
+ 
 #ifndef __SEAHORSE_PREFS_H__
 #define __SEAHORSE_PREFS_H__
 
 #include "seahorse-context.h"
 #include "seahorse-widget.h"
 
-SeahorseWidget *    seahorse_prefs_new          (SeahorseContext *sctx);
+SeahorseWidget *    seahorse_prefs_new          (void);
 
 void                seahorse_prefs_add_tab      (SeahorseWidget *swidget,
                                                  GtkWidget *label,
                                                  GtkWidget *tab);
                                                  
 void                seahorse_prefs_select_tab   (SeahorseWidget *swidget,
-                                                 guint tab);
+                                                 GtkWidget *tab);
 
-#endif /* __SEAHORSE_PREFERENCES_H__ */                                                  
+void                seahorse_prefs_select_tabid (SeahorseWidget *swidget,
+                                                 const gchar *tab);
+
+void                seahorse_prefs_remove_tab   (SeahorseWidget *swidget,
+                                                 GtkWidget *tab);
+
+#endif /* __SEAHORSE_PREFERENCES_H__ */       
