@@ -63,7 +63,8 @@ gchar*               seahorse_ssh_operation_sync         (SeahorseSSHSource *ssr
 SeahorseOperation*   seahorse_ssh_operation_upload       (SeahorseSSHSource *ssrc,
                                                           GList *keys,
                                                           const gchar *username,
-                                                          const gchar *hostname);
+                                                          const gchar *hostname, 
+                                                          const gchar *port);
 
 /* result: the generated SeahorseKey */
 SeahorseOperation*   seahorse_ssh_operation_generate     (SeahorseSSHSource *src, 
@@ -92,5 +93,10 @@ SeahorseOperation*   seahorse_ssh_operation_import_private (SeahorseSSHSource *s
 SeahorseOperation*  seahorse_ssh_operation_authorize       (SeahorseSSHSource *ssrc,
                                                             SeahorseSSHKey *skey,
                                                             gboolean authorize);
-                                                            
+
+/* result: nothing */
+SeahorseOperation*  seahorse_ssh_operation_rename          (SeahorseSSHSource *ssrc,
+                                                            SeahorseSSHKey *skey,
+                                                            const gchar *newcomment);
+
 #endif /* __SEAHORSE_SSH_OPERATION_H__ */
