@@ -27,6 +27,7 @@
 #include <time.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <string.h>
 
 #include <gnome.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -218,36 +219,36 @@ seahorse_util_set_text_view_string (GtkTextView *view, GString *string)
 /**
  * seahorse_util_write_data_to_text:
  * @data: Data to write
- * @release: Whether to release @data or not
+ * @len: Length of the data
  *
  * Converts @data to a string. 
  *
  * Returns: The string read from data
  **/
 gchar*
-seahorse_util_write_data_to_text (gpgme_data_t data, gboolean release)
+seahorse_util_write_data_to_text (gpgme_data_t data, guint *len)
 {
-	gint size = 128;
+    gint size = 128;
     gchar *buffer, *text;
     guint nread = 0;
-	GString *string;
+    GString *string;
 
     gpgme_data_seek (data, 0, SEEK_SET);
 
-	string = g_string_new ("");
-	buffer = g_new (gchar, size);
-	
-	while ((nread = gpgme_data_read (data, buffer, size)) > 0)
-		string = g_string_append_len (string, buffer, nread);
-
-    if (release)
-        gpgmex_data_release (data);
+    string = g_string_new ("");
+    buffer = g_new (gchar, size);
     
-	text = string->str;
-	g_string_free (string, FALSE);
+    while ((nread = gpgme_data_read (data, buffer, size)) > 0)
+        string = g_string_append_len (string, buffer, nread);
+
+    if (len)
+        *len = string->len;
+    
+    text = string->str;
+    g_string_free (string, FALSE);
     g_free (buffer);
-	
-	return text;
+    
+    return text;
 }
 
 /** 
@@ -403,6 +404,8 @@ seahorse_util_uri_get_last (const gchar* uri)
 {
     const gchar* t;
     
+    g_return_val_if_fail (uri, NULL);
+    
     t = uri + strlen (uri);
     
     if (*(t - 1) == '/' && t != uri)
@@ -724,7 +727,9 @@ seahorse_util_detect_mime_type (const gchar *mime)
         return SKEY_PGP;
     
 #ifdef WITH_SSH 
-    else if (g_ascii_strcasecmp (mime, "application/ssh-key") == 0)
+    /* TODO: For now all PEM keys are treated as SSH keys */
+    else if (g_ascii_strcasecmp (mime, "application/x-ssh-key") == 0 ||
+             g_ascii_strcasecmp (mime, "application/x-pem-key") == 0)
         return SKEY_SSH;
 #endif 
     
@@ -809,7 +814,11 @@ seahorse_util_chooser_show_key_files (GtkWidget *dialog)
        cases that extension is associated with text/plain */
     gtk_file_filter_set_name (filter, _("All key files"));
     gtk_file_filter_add_mime_type (filter, "application/pgp-keys");
-    gtk_file_filter_add_pattern (filter, "*.asc");    
+#ifdef WITH_SSH 
+    gtk_file_filter_add_mime_type (filter, "application/x-ssh-key");
+    gtk_file_filter_add_mime_type (filter, "application/x-pem-key");
+#endif
+    gtk_file_filter_add_pattern (filter, "*.asc");
     gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);    
     gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
 
@@ -1048,6 +1057,15 @@ seahorse_util_strvec_dup (const gchar** vec)
     return ret;
 }
 
+guint 
+seahorse_util_strvec_length (const gchar **vec)
+{
+    guint len = 0;
+    while (*(vec++))
+        len++;
+    return len;
+}
+
 /* TODO: This function no longer makes sense once we 
    have multiple key and encryption types */
 gpgme_key_t* 
@@ -1071,6 +1089,8 @@ void
 seahorse_util_free_keys (gpgme_key_t* keys)
 {
     gpgme_key_t* k = keys;
+    if (!keys)
+        return;
     while (*k)
         gpgmex_key_unref (*(k++));
     g_free (keys);
@@ -1162,7 +1182,7 @@ seahorse_util_string_up_first (const gchar *orig)
     /* Just use ASCII functions when not UTF8 */        
     } else {
         ret = g_strdup (orig);
-        g_ascii_toupper (ret[0]);
+        ret[0] = g_ascii_toupper (ret[0]);
     }
     
     return ret;
@@ -1210,6 +1230,49 @@ seahorse_util_string_slist_equal (GSList *l1, GSList *l2)
     return !l1 && !l2;   
 }
 
+gboolean 
+seahorse_util_string_is_whitespace (const gchar *text)
+{
+    g_assert (text);
+    g_assert (g_utf8_validate (text, -1, NULL));
+    
+    while (*text) {
+        if (!g_unichar_isspace (g_utf8_get_char (text)))
+            return FALSE;
+        text = g_utf8_next_char (text);
+    }
+    return TRUE;
+}
+
+void
+seahorse_util_string_trim_whitespace (gchar *text)
+{
+    gchar *b, *e, *n;
+    
+    g_assert (text);
+    g_assert (g_utf8_validate (text, -1, NULL));
+    
+    /* Trim the front */
+    b = text;
+    while (*b && g_unichar_isspace (g_utf8_get_char (b)))
+        b = g_utf8_next_char (b);
+    
+    /* Trim the end */
+    n = e = b + strlen (b);
+    while (n >= b) {
+        if (*n && !g_unichar_isspace (g_utf8_get_char (n)))
+            break;
+        e = n;
+        n = g_utf8_prev_char (e);
+    }
+    
+    g_assert (b >= text);
+    g_assert (e >= b);
+
+    *e = 0;
+    g_memmove (text, b, (e + 1) - b);
+}
+
 /* Callback to determine where a popup menu should be placed */
 void
 seahorse_util_determine_popup_menu_position (GtkMenu *menu, int *x, int *y,
