@@ -40,9 +40,8 @@ const AvahiPoll* seahorse_util_dns_sd_get_poll ();
 #endif
 
 typedef enum {
-	SEAHORSE_CRYPT_SUFFIX,
-	SEAHORSE_SIG_SUFFIX,
-	SEAHORSE_ASC_SUFFIX
+    SEAHORSE_CRYPT_SUFFIX,
+    SEAHORSE_SIG_SUFFIX,
 } SeahorseSuffix;
 
 #define SEAHORSE_EXT_ASC ".asc"
@@ -72,13 +71,9 @@ void        seahorse_util_handle_gpgme          (gpgme_error_t      err,
 
 void        seahorse_util_handle_error          (GError*            err,
                                                  const char*        desc, ...);
-                                                 
-gpgme_error_t	seahorse_util_write_data_to_file (const gchar       *path,
-							                     gpgme_data_t       data,
-                                                 gboolean           release);
 
-gchar*		seahorse_util_write_data_to_text	(gpgme_data_t       data,
-                                                 gboolean           release);
+gchar*      seahorse_util_write_data_to_text    (gpgme_data_t       data,
+                                                 guint              *len);
 
 guint       seahorse_util_read_data_block       (GString            *buf, 
                                                  gpgme_data_t       data, 
@@ -109,6 +104,17 @@ gchar**     seahorse_util_uris_expand       (const gchar **uris);
 gboolean    seahorse_util_uris_package      (const gchar* package, 
                                              const gchar** uris);
 
+GQuark      seahorse_util_detect_mime_type   (const gchar *mime);
+
+GQuark      seahorse_util_detect_data_type   (const gchar *data,
+                                              guint length);
+
+GQuark      seahorse_util_detect_file_type   (const gchar *uri);
+
+gboolean    seahorse_util_write_file_private            (const gchar* filename,
+                                                         const gchar* contents,
+                                                         GError **err);
+
 GtkWidget*  seahorse_util_chooser_open_new              (const gchar *title,
                                                          GtkWindow *parent);
 
@@ -117,8 +123,6 @@ GtkWidget*  seahorse_util_chooser_save_new              (const gchar *title,
 
 void        seahorse_util_chooser_show_key_files        (GtkWidget *dialog);
 
-void        seahorse_util_chooser_show_jpeg_files       (GtkWidget *dialog);
-
 void        seahorse_util_chooser_show_archive_files    (GtkWidget *dialog);
 
 void        seahorse_util_chooser_set_filename          (GtkWidget *dialog, 
@@ -140,6 +144,8 @@ gchar*      seahorse_util_remove_suffix     (const gchar        *path,
 
 gchar**     seahorse_util_strvec_dup        (const gchar        **vec);
 
+guint       seahorse_util_strvec_length       (const gchar      **vec);
+
 gpgme_key_t* seahorse_util_keylist_to_keys    (GList *keys);
 
 GList*       seahorse_util_keylist_sort       (GList *keys);
@@ -160,10 +166,21 @@ GSList*     seahorse_util_string_slist_copy   (GSList *slist);
 
 gboolean    seahorse_util_string_slist_equal  (GSList *sl1, GSList *sl2);
 
-#define     seahorse_util_wait_until(expr)          \
-    while (!(expr)) {                               \
-        g_thread_yield ();                          \
-        g_main_context_iteration (NULL, FALSE);     \
+gboolean    seahorse_util_string_is_whitespace (const gchar *text);
+
+void        seahorse_util_string_trim_whitespace (gchar *text);
+
+void        seahorse_util_determine_popup_menu_position  (GtkMenu *menu,
+                                                           int *x,
+                                                           int *y,
+                                                           gboolean *push_in,
+                                                           gpointer gdata);
+
+#define     seahorse_util_wait_until(expr)                \
+    while (!(expr)) {                                     \
+        while (g_main_context_pending(NULL) && !(expr))   \
+            g_main_context_iteration (NULL, FALSE);       \
+        g_thread_yield ();                                \
     }
 
 #ifdef _DEBUG
