@@ -20,12 +20,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <gnome.h>
 #include <glade/glade.h>
 #include <glade/glade-build.h>
 
 #include "seahorse-widget.h"
-#include "config.h"
 #include "seahorse-gtkstock.h"
 
 #define STATUS "status"
@@ -152,46 +152,41 @@ object_finalize (GObject *gobject)
 static void
 object_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
-	SeahorseWidget *swidget;
+    SeahorseWidget *swidget;
     GtkWidget *w;
     GdkPixbuf *pixbuf = NULL;
-	char *path;
-	
-	swidget = SEAHORSE_WIDGET (object);
-	
-	switch (prop_id) {
-		/* Loads xml definition from name, connects common callbacks */
-		case PROP_NAME:
-            g_return_if_fail (swidget->name == NULL);
-			swidget->name = g_value_dup_string (value);
-			path = g_strdup_printf ("%sseahorse-%s.glade",
-			                        SEAHORSE_GLADEDIR, swidget->name);
-			swidget->xml = glade_xml_new (path, swidget->name, NULL);
-			g_free (path);
-			g_assert (swidget->xml != NULL);
-			
-			glade_xml_signal_connect_data (swidget->xml, "closed",
-				G_CALLBACK (widget_closed), swidget);
-			glade_xml_signal_connect_data (swidget->xml, "delete_event",
-				G_CALLBACK (widget_delete_event), swidget);
-			glade_xml_signal_connect_data (swidget->xml, "help",
-				G_CALLBACK (widget_help), swidget);
+    char *path;
+    
+    swidget = SEAHORSE_WIDGET (object);
+    
+    switch (prop_id) {
+    /* Loads xml definition from name, connects common callbacks */
+    case PROP_NAME:
+        g_return_if_fail (swidget->name == NULL);
+        swidget->name = g_value_dup_string (value);
+        path = g_strdup_printf ("%sseahorse-%s.glade",
+                                SEAHORSE_GLADEDIR, swidget->name);
+        swidget->xml = glade_xml_new (path, swidget->name, NULL);
+        g_free (path);
+        g_return_if_fail (swidget->xml != NULL);
         
-            w = glade_xml_get_widget (swidget->xml, swidget->name);
-            glade_xml_set_toplevel (swidget->xml, GTK_WINDOW (w));
-            glade_xml_ensure_accel (swidget->xml);
-            
-            pixbuf = gtk_widget_render_icon (w, 
-                                     SEAHORSE_STOCK_SEAHORSE, 
-                                     (GtkIconSize)-1, 
-                                     NULL); 
-            gtk_window_set_icon (GTK_WINDOW (w), gdk_pixbuf_copy(pixbuf));
-            g_object_unref(pixbuf);
-			break;
-            
-		default:
-			break;
-	}
+        glade_xml_signal_connect_data (swidget->xml, "closed",
+                                       G_CALLBACK (widget_closed), swidget);
+        glade_xml_signal_connect_data (swidget->xml, "delete_event",
+                                       G_CALLBACK (widget_delete_event), swidget);
+        glade_xml_signal_connect_data (swidget->xml, "help",
+                                       G_CALLBACK (widget_help), swidget);
+        
+        w = glade_xml_get_widget (swidget->xml, swidget->name);
+        glade_xml_set_toplevel (swidget->xml, GTK_WINDOW (w));
+        glade_xml_ensure_accel (swidget->xml);
+        
+        pixbuf = gtk_widget_render_icon (w, SEAHORSE_STOCK_SEAHORSE, 
+                                         (GtkIconSize)-1, NULL); 
+        gtk_window_set_icon (GTK_WINDOW (w), gdk_pixbuf_copy(pixbuf));
+        g_object_unref(pixbuf);
+        break;
+    }
 }
 
 static void
@@ -239,27 +234,22 @@ widget_delete_event (GtkWidget *widget, GdkEvent *event, SeahorseWidget *swidget
  * Returns: The new #SeahorseWidget, or NULL if the widget already exists
  **/
 SeahorseWidget*
-seahorse_widget_new (gchar *name)
+seahorse_widget_new (const gchar *name)
 {
-	SeahorseWidget *swidget;
-	
-	/* Check if have widget hash */
-	if (widgets != NULL) {
-		swidget = g_hash_table_lookup (widgets, name);
-		
-		/* If widget already exists, present */
-		if (swidget != NULL) {
-			gtk_window_present (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
-			return NULL;
-		}
-	}
-	/* Else create new widget hash */
-	else
-		widgets = g_hash_table_new ((GHashFunc)g_str_hash, (GCompareFunc)g_str_equal);
-	
-	/* If widget doesn't already exist, create & insert into hash */
-	swidget = g_object_new (SEAHORSE_TYPE_WIDGET, "name", name, NULL);
-	g_hash_table_insert (widgets, g_strdup (name), swidget);
+    /* Check if have widget hash */
+    SeahorseWidget *swidget = seahorse_widget_find (name);
+    
+    /* If widget already exists, present */
+    if (swidget != NULL) {
+        gtk_window_present (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
+        return NULL;
+    }
+
+    /* If widget doesn't already exist, create & insert into hash */
+    swidget = g_object_new (SEAHORSE_TYPE_WIDGET, "name", name, NULL);
+    if(!widgets)
+        widgets = g_hash_table_new ((GHashFunc)g_str_hash, (GCompareFunc)g_str_equal);
+    g_hash_table_insert (widgets, g_strdup (name), swidget);
 
     /* We don't care about this floating business */
     g_object_ref (GTK_OBJECT (swidget));
@@ -277,7 +267,7 @@ seahorse_widget_new (gchar *name)
  * Returns: The new #SeahorseWidget
  **/
 SeahorseWidget*
-seahorse_widget_new_allow_multiple (gchar *name)
+seahorse_widget_new_allow_multiple (const gchar *name)
 {
     SeahorseWidget *swidget = g_object_new (SEAHORSE_TYPE_WIDGET, "name", name,  NULL);
     
@@ -288,6 +278,15 @@ seahorse_widget_new_allow_multiple (gchar *name)
     return swidget;
 }
 
+SeahorseWidget*
+seahorse_widget_find (const gchar *name)
+{
+    /* Check if have widget hash */
+    if (widgets != NULL)
+        return SEAHORSE_WIDGET (g_hash_table_lookup (widgets, name));
+    return NULL;
+}
+
 /**
  * seahorse_widget_show_help
  * @swidget: The #SeahorseWidget.
@@ -299,7 +298,8 @@ seahorse_widget_show_help (SeahorseWidget *swidget)
 {
     GError *err = NULL;
 
-    if (g_str_equal (swidget->name, "key-manager"))
+    if (g_str_equal (swidget->name, "key-manager") || 
+        g_str_equal (swidget->name, "keyserver-results"))
         gnome_help_display (PACKAGE, "introduction", &err);
     else
         gnome_help_display (PACKAGE, swidget->name, &err);
@@ -307,7 +307,7 @@ seahorse_widget_show_help (SeahorseWidget *swidget)
     if (err != NULL) {
         GtkWidget *dialog;
 
-        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, 
+        dialog = gtk_message_dialog_new (GTK_WINDOW (seahorse_widget_get_top (swidget)), GTK_DIALOG_MODAL, 
                                          GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
                                          _("Could not display help: %s"),
                                          err->message);
@@ -357,6 +357,7 @@ seahorse_widget_show (SeahorseWidget *swidget)
         gtk_ui_manager_ensure_update (swidget->ui);
 
     widget = glade_xml_get_widget (swidget->xml, swidget->name);
+    g_return_if_fail (widget != NULL);
     gtk_widget_show (widget);
 }
  
@@ -382,9 +383,11 @@ seahorse_widget_set_visible (SeahorseWidget *swidget, const char *identifier,
 void
 seahorse_widget_destroy (SeahorseWidget *swidget)
 {
-	g_return_if_fail (swidget != NULL && SEAHORSE_IS_WIDGET (swidget));
-	
-	g_object_unref (swidget);
+    g_return_if_fail (swidget != NULL && SEAHORSE_IS_WIDGET (swidget));
+    if (!swidget->destroying) {
+        swidget->destroying = TRUE;
+        g_object_unref (swidget);
+    }
 }
 
 /* UI MANAGER CODE ---------------------------------------------------------- */
